# dnstest

A cli tool for testing DNS records match a provided yaml config file.

[![Build Status](https://travis-ci.org/leonsmith/dnstest.svg?branch=master)](https://travis-ci.org/leonsmith/dnstest)
[![Python Versions](https://img.shields.io/pypi/pyversions/dnstest.svg)](https://pypi.org/project/dnstest/)
[![License](https://img.shields.io/pypi/l/dnstest.svg?color=informational)](https://pypi.org/project/dnstest/)

## Versioning

dnstest follows [SemVer](https://semver.org/) (MAJOR.MINOR.PATCH) to track what is in each release.

* Major version number will be bumped when there is an incompatible API change
* Minor version number will be bumped when there is functionality added in a backwards-compatible manner.
* Patch version number will be bumped when there is backwards-compatible bug fixes.

Additional labels for pre-release and build metadata are available as extensions to the MAJOR.MINOR.PATCH format.


## Installation

Installation the package from pypi with your tool of choice `pip`, `poetry`
or `pipenv`.

```bash
pip install dnstest
```

## Usage

TODO:

`dnstest ./example-config.yml`


## Documentation

TODO:

https://github.com/leonsmith/dnstest/


## Support
*If you’re interested in financially supporting open source, consider donating.*


[![XLM Wallet](https://img.shields.io/keybase/xlm/leonsmith.svg)](https://keybase.io/leonsmith)
[![BTC Wallet](https://img.shields.io/keybase/btc/leonsmith.svg)](https://keybase.io/leonsmith)
